@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
 import sympy
 
 from qibo.config import EINSUM_CHARS, log, raise_error
 from qibo.hamiltonians.abstract import AbstractHamiltonian
+from qibo.symbols import Z
 
 
 class Hamiltonian(AbstractHamiltonian):
@@ -114,12 +114,10 @@ class Hamiltonian(AbstractHamiltonian):
         if isinstance(state, self.backend.tensor_types):
             shape = tuple(state.shape)
             if len(shape) == 1:  # state vector
-                return self.backend.calculate_expectation_state(
-                    self.matrix, state, normalize
-                )
+                return self.backend.calculate_expectation_state(self, state, normalize)
             elif len(shape) == 2:  # density matrix
                 return self.backend.calculate_expectation_density_matrix(
-                    self.matrix, state, normalize
+                    self, state, normalize
                 )
             else:
                 raise_error(
@@ -136,6 +134,25 @@ class Hamiltonian(AbstractHamiltonian):
                 "".format(type(state)),
             )
 
+    def expectation_from_samples(self, freq, qubit_map=None):
+        import numpy as np
+
+        obs = self.matrix
+        if np.count_nonzero(obs - np.diag(np.diagonal(obs))) != 0:
+            raise_error(NotImplementedError, "Observable is not diagonal.")
+        keys = list(freq.keys())
+        if qubit_map is None:
+            qubit_map = list(range(int(np.log2(len(obs)))))
+        counts = np.array(list(freq.values())) / sum(freq.values())
+        expval = 0
+        kl = len(qubit_map)
+        for j, k in enumerate(keys):
+            index = 0
+            for i in qubit_map:
+                index += int(k[qubit_map.index(i)]) * 2 ** (kl - 1 - i)
+            expval += obs[index, index] * counts[j]
+        return expval
+
     def eye(self, n=None):
         if n is None:
             n = int(self.matrix.shape[0])
@@ -537,6 +554,42 @@ class SymbolicHamiltonian(AbstractHamiltonian):
     def expectation(self, state, normalize=False):
         return Hamiltonian.expectation(self, state, normalize)
 
+    def expectation_from_samples(self, freq, qubit_map=None):
+        import numpy as np
+
+        terms = self.terms
+        for term in terms:
+            for factor in term.factors:
+                if isinstance(factor, Z) == False:
+                    raise_error(
+                        NotImplementedError, "Observable is not a Z Pauli string."
+                    )
+            if len(term.factors) != len(set(term.factors)):
+                raise_error(NotImplementedError, "Z^k is not implemented since Z^2=I.")
+        keys = list(freq.keys())
+        counts = np.array(list(freq.values())) / sum(freq.values())
+        coeff = list(self.form.as_coefficients_dict().values())
+        qubits = []
+        for term in terms:
+            qubits_term = []
+            for k in term.target_qubits:
+                qubits_term.append(k)
+            qubits.append(qubits_term)
+        if qubit_map is None:
+            qubit_map = list(range(len(keys[0])))
+        expval = 0
+        for j, q in enumerate(qubits):
+            subk = []
+            expval_q = 0
+            for i, k in enumerate(keys):
+                subk = [int(k[qubit_map.index(s)]) for s in q]
+                expval_k = 1
+                if subk.count(1) % 2 == 1:
+                    expval_k = -1
+                expval_q += expval_k * counts[i]
+            expval += expval_q * float(coeff[j])
+        return expval
+
     def __add__(self, o):
         if isinstance(o, self.__class__):
             if self.nqubits != o.nqubits:
@@ -664,7 +717,7 @@ class SymbolicHamiltonian(AbstractHamiltonian):
                 self.backend,
                 self.backend.cast(state, copy=True),
                 self.nqubits,
-                density_matrix,
+                density_matrix=density_matrix,
             )
         if self.constant:  # pragma: no cover
             total += self.constant * state
