@@ -1,8 +1,9 @@
-# -*- coding: utf-8 -*-
+import numpy as np
 import pytest
 
-from qibo import gates
+from qibo import gates, hamiltonians
 from qibo.models import Circuit
+from qibo.symbols import I, Z
 
 
 @pytest.mark.parametrize("target", range(5))
@@ -53,3 +54,26 @@ def test_state_representation_max_terms(backend, density_matrix):
             result.symbolic(max_terms=5)
             == "(0.17678+0j)|00000> + (0.17678+0j)|00001> + (0.17678+0j)|00010> + (0.17678+0j)|00011> + (0.17678+0j)|00100> + ..."
         )
+
+
+@pytest.mark.parametrize("density_matrix", [False, True])
+def test_expectation_from_samples(backend, density_matrix):
+
+    obs0 = 2 * Z(0) * Z(1) + Z(0) * Z(2)
+    obs1 = 2 * Z(0) * Z(1) + Z(0) * Z(2) * I(3)
+    h_sym = hamiltonians.SymbolicHamiltonian(obs0, backend=backend)
+    h_dense = hamiltonians.Hamiltonian(3, h_sym.matrix, backend=backend)
+    h1 = hamiltonians.SymbolicHamiltonian(obs1, backend=backend)
+    c = Circuit(4)
+    c.add(gates.RX(0, np.random.rand()))
+    c.add(gates.RX(1, np.random.rand()))
+    c.add(gates.RX(2, np.random.rand()))
+    c.add(gates.RX(3, np.random.rand()))
+    c.add(gates.M(0, 1, 2))
+    nshots = 10**5
+    result = c(nshots=nshots)
+    expval_sym = result.expectation_from_samples(h_sym)
+    expval_dense = result.expectation_from_samples(h_dense)
+    expval = h1.expectation(result.state())
+    backend.assert_allclose(expval_sym, expval_dense)
+    backend.assert_allclose(expval_sym, expval, atol=10 / np.sqrt(nshots))
